@@ -37,7 +37,7 @@
 #include "siproxd.h"
 #include "log.h"
 
-static char const ident[]="$Id: auth.c,v 1.24 2008/01/19 16:07:14 hb9xar Exp $";
+static char const ident[]="$Id: auth.c,v 1.26 2008/07/22 11:17:49 hb9xar Exp $";
 
 /* configuration storage */
 extern struct siproxd_config configuration;
@@ -220,7 +220,7 @@ static int auth_check(osip_proxy_authorization_t *proxy_auth) {
 
    DEBUGC(DBCLASS_BABBLE,"calculated Response=\"%s\"", Lcl_Response);
 
-   if (strcmp(Lcl_Response, Response)==0) {
+   if (strcmp((char*)Lcl_Response, Response)==0) {
       DEBUGC(DBCLASS_AUTH,"Authentication succeeded");
       sts = STS_SUCCESS;
    } else {
@@ -367,25 +367,30 @@ void DigestCalcHA1(
 		   OUT HASHHEX SessionKey
 		   )
 {
-  MD5_CTX Md5Ctx;
+  osip_MD5_CTX Md5Ctx;
   HASH HA1;
   
-  MD5Init(&Md5Ctx);
-  if (pszUserName) MD5Update(&Md5Ctx, pszUserName, strlen(pszUserName));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszRealm)    MD5Update(&Md5Ctx, pszRealm, strlen(pszRealm));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszPassword) MD5Update(&Md5Ctx, pszPassword, strlen(pszPassword));
-  MD5Final(HA1, &Md5Ctx);
+  osip_MD5Init(&Md5Ctx);
+  if (pszUserName) osip_MD5Update(&Md5Ctx, (unsigned char*)pszUserName, 
+                                  strlen(pszUserName));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszRealm)    osip_MD5Update(&Md5Ctx, (unsigned char*)pszRealm,
+                                  strlen(pszRealm));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszPassword) osip_MD5Update(&Md5Ctx, (unsigned char*)pszPassword,
+                                  strlen(pszPassword));
+  osip_MD5Final(HA1, &Md5Ctx);
 
   if ((pszAlg!=NULL) && (osip_strcasecmp(pszAlg, "md5-sess") == 0)) {
-    MD5Init(&Md5Ctx);
-    MD5Update(&Md5Ctx, HA1, HASHLEN);
-    MD5Update(&Md5Ctx, ":", 1);
-    if (pszNonce)  MD5Update(&Md5Ctx, pszNonce, strlen(pszNonce));
-    MD5Update(&Md5Ctx, ":", 1);
-    if (pszCNonce) MD5Update(&Md5Ctx, pszCNonce, strlen(pszCNonce));
-    MD5Final(HA1, &Md5Ctx);
+    osip_MD5Init(&Md5Ctx);
+    osip_MD5Update(&Md5Ctx, HA1, HASHLEN);
+    osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+    if (pszNonce)  osip_MD5Update(&Md5Ctx, (unsigned char*)pszNonce,
+                                  strlen(pszNonce));
+    osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+    if (pszCNonce) osip_MD5Update(&Md5Ctx, (unsigned char*)pszCNonce,
+                                  strlen(pszCNonce));
+    osip_MD5Final(HA1, &Md5Ctx);
   };
   CvtHex(HA1, SessionKey);
 }
@@ -403,57 +408,59 @@ void DigestCalcResponse(
 			OUT HASHHEX Response    /* request-digest or response-digest */
 			)
 {
-  MD5_CTX Md5Ctx;
+  osip_MD5_CTX Md5Ctx;
   HASH HA2;
   HASH RespHash;
   HASHHEX HA2Hex;
   
   /* calculate H(A2) */
-  MD5Init(&Md5Ctx);
-  if (pszMethod)   MD5Update(&Md5Ctx, pszMethod, strlen(pszMethod));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszDigestUri)MD5Update(&Md5Ctx, pszDigestUri, strlen(pszDigestUri));
+  osip_MD5Init(&Md5Ctx);
+  if (pszMethod)    osip_MD5Update(&Md5Ctx, (unsigned char*)pszMethod,
+                                   strlen(pszMethod));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszDigestUri) osip_MD5Update(&Md5Ctx, (unsigned char*)pszDigestUri,
+                                   strlen(pszDigestUri));
   
   if (pszQop!=NULL) {
       goto auth_withqop;
   };
   
   /* auth_withoutqop: */
-  MD5Final(HA2, &Md5Ctx);
+  osip_MD5Final(HA2, &Md5Ctx);
   CvtHex(HA2, HA2Hex);
 
   /* calculate response */
-  MD5Init(&Md5Ctx);
-  MD5Update(&Md5Ctx, HA1, HASHHEXLEN);
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszNonce)    MD5Update(&Md5Ctx, pszNonce, strlen(pszNonce));
-  MD5Update(&Md5Ctx, ":", 1);
+  osip_MD5Init(&Md5Ctx);
+  osip_MD5Update(&Md5Ctx, HA1, HASHHEXLEN);
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszNonce)    osip_MD5Update(&Md5Ctx, (unsigned char*)pszNonce, strlen(pszNonce));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
 
   goto end;
 
  auth_withqop:
 
-  MD5Update(&Md5Ctx, ":", 1);
-  MD5Update(&Md5Ctx, HEntity, HASHHEXLEN);
-  MD5Final(HA2, &Md5Ctx);
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  osip_MD5Update(&Md5Ctx, HEntity, HASHHEXLEN);
+  osip_MD5Final(HA2, &Md5Ctx);
   CvtHex(HA2, HA2Hex);
 
   /* calculate response */
-  MD5Init(&Md5Ctx);
-  MD5Update(&Md5Ctx, HA1, HASHHEXLEN);
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszNonce)    MD5Update(&Md5Ctx, pszNonce, strlen(pszNonce));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszNonceCount)MD5Update(&Md5Ctx, pszNonceCount, strlen(pszNonceCount));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszCNonce)   MD5Update(&Md5Ctx, pszCNonce, strlen(pszCNonce));
-  MD5Update(&Md5Ctx, ":", 1);
-  if (pszQop)      MD5Update(&Md5Ctx, pszQop, strlen(pszQop));
-  MD5Update(&Md5Ctx, ":", 1);
+  osip_MD5Init(&Md5Ctx);
+  osip_MD5Update(&Md5Ctx, HA1, HASHHEXLEN);
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszNonce)    osip_MD5Update(&Md5Ctx, (unsigned char*)pszNonce, strlen(pszNonce));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszNonceCount)osip_MD5Update(&Md5Ctx, (unsigned char*)pszNonceCount, strlen(pszNonceCount));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszCNonce)   osip_MD5Update(&Md5Ctx, (unsigned char*)pszCNonce, strlen(pszCNonce));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
+  if (pszQop)      osip_MD5Update(&Md5Ctx, (unsigned char*)pszQop, strlen(pszQop));
+  osip_MD5Update(&Md5Ctx, (unsigned char*)":", 1);
 
  end:
-  MD5Update(&Md5Ctx, HA2Hex, HASHHEXLEN);
-  MD5Final(RespHash, &Md5Ctx);
+  osip_MD5Update(&Md5Ctx, HA2Hex, HASHHEXLEN);
+  osip_MD5Final(RespHash, &Md5Ctx);
   CvtHex(RespHash, Response);
 }
 
