@@ -1,15 +1,15 @@
 
 /* TAKEN from rcf2617.txt */
 
-/* $Id: digcalc.h,v 1.2 2004/04/11 10:40:00 hb9xar Exp $ */
+/* $Id: digcalc.h,v 1.3 2008/07/22 11:17:49 hb9xar Exp $ */
 
 #ifndef _DIGCALC_H_
 #define _DIGCALC_H_
 
 #define HASHLEN 16
-typedef char HASH[HASHLEN];
+typedef unsigned char HASH[HASHLEN];
 #define HASHHEXLEN 32
-typedef char HASHHEX[HASHHEXLEN+1];
+typedef unsigned char HASHHEX[HASHHEXLEN+1];
 #define IN
 #define OUT
 
