@@ -37,7 +37,7 @@
 #include "plugins.h"
 #include "log.h"
 
-static char const ident[]="$Id: proxy.c,v 1.113 2008/02/24 18:29:31 hb9xar Exp $";
+static char const ident[]="$Id: proxy.c,v 1.117 2009/07/30 17:20:55 hb9xar Exp $";
 
 /* configuration storage */
 extern struct siproxd_config configuration;	/* defined in siproxd.c */
@@ -266,8 +266,8 @@ sts=sip_obscure_callid(ticket);
    } else {
       if (max_forwards->hvalue) {
          forwards_count = atoi(max_forwards->hvalue);
-         if ((forwards_count<=0)||
-             (forwards_count>=LONG_MAX)) forwards_count=DEFAULT_MAXFWD;
+         if ((forwards_count<0)||
+             (forwards_count>255)) forwards_count=DEFAULT_MAXFWD;
          forwards_count -=1;
          osip_free (max_forwards->hvalue);
       }
@@ -800,8 +800,9 @@ int proxy_rewrite_invitation_body(sip_ticket_t *ticket, int direction){
       return STS_FAILURE;
    }
 
-   DEBUGC(-1, "rewrite_invitation_body: payload %ld bytes", (long)buflen);
-   DUMP_BUFFER(-1, buff, buflen);
+   DEBUGC(DBCLASS_PROXY, "rewrite_invitation_body: payload %ld bytes", 
+          (long)buflen);
+   DUMP_BUFFER(DBCLASS_PROXY, buff, buflen);
 
    sts = sdp_message_init(&sdp);
    sts = sdp_message_parse (sdp, buff);
@@ -978,47 +979,82 @@ if (configuration.debuglevel)
          if ((msg_port > 0) && (msg_port <= 65535)) {
             client_id_t client_id;
             osip_contact_t *contact = NULL;
-            char *tmp=NULL;
             char *protocol=NULL;
 
             /* try to get some additional UA specific unique ID.
              * This Client-ID should be guaranteed persistent
              * and not depend on if a UA/Server does include a
              * particular Header (Contact) or not.
-             * I should just go for the remote IP address here, no?
-             */
-            /* &&& NO, using the sender IP will cause troubles if
-             * the remote peer (Proxy/registrar) is thrown out of
-             * the signalling path. Then suddenly the IP address changes.
-             *
-             * I should probably go back to the Contact Header based idea,
-             * with fallback to IP.
-             * I must use a n-item structure, including all things that
-             * can be used for comparing. Then, in the RTP proxy, comparison
-             * must take place according to priorities with the item
-             * with highest priority present in the RTP table *and*
-             * extracted from the SIP message.
-             * To start with, this can be just 2 things, the Contact header
-             * and the Layer 3 IP address. As long as the UAs include the
-             * Contact header, we survive IP changes (e.g. when the SIP
-             * Registrar/Proxy is removed from signalling path within an
-             * ongoing call. This may happen if the Registrar/Proxy does
-             * not explicitely ask to stay in the signalling path using 
-             * Record-Route headers - which is perfectly legal
-             *
              */
+            /* we will use - if present the from/to fields.
+              * Outgoing call (RQ out, RS in  => use the "from" field to identify local client
+              * Incoming call (RQ in,  RS out => use the "to" field to identify local client
+              *
+              * According to RFC3261, the From and To headers MUST NOT change
+              * withing an ongoing dialog:
+              *
+              * 8.2.6.2 Headers and Tags
+              *
+              *    The From field of the response MUST equal the From header field of
+              *    the request.  The Call-ID header field of the response MUST equal the
+              *    Call-ID header field of the request.  The CSeq header field of the
+              *    response MUST equal the CSeq field of the request.  The Via header
+              *    field values in the response MUST equal the Via header field values
+              *    in the request and MUST maintain the same ordering.
+              *
+              *    If a request contained a To tag in the request, the To header field
+              *    in the response MUST equal that of the request.  However, if the To
+              *    header field in the request did not contain a tag, the URI in the To
+              *    header field in the response MUST equal the URI in the To header
+              *    field; additionally, the UAS MUST add a tag to the To header field in
+              *    the response (with the exception of the 100 (Trying) response, in
+              *    [...]
+              */
+
+             /* If no proper TO/FROM headers are present, fall back to use Contact header... */
 
             memset(&client_id, 0, sizeof(client_id));
 
-            /* get the Contact Header if present */
-            osip_message_get_contact(mymsg, 0, &contact);
-            if (contact) osip_contact_to_str(contact, &tmp);
-            if (tmp) strncpy(client_id.contact, tmp, CLIENT_ID_SIZE-1);
+             /* Outgoing call (RQ out, RS in  => use the "from" field to identify local client */
+            if ((MSG_IS_REQUEST(mymsg) && direction == DIR_OUTGOING) ||
+                (!MSG_IS_REQUEST(mymsg) && direction == DIR_INCOMING)) {
+
+                /* I have a full FROM SIP URI 'user@host' */
+                if (mymsg->from && mymsg->from->url && 
+                    mymsg->from->url->username && mymsg->from->url->host) {
+                   snprintf(client_id.idstring, CLIENT_ID_SIZE-1, "%s@%s", 
+                            mymsg->from->url->username, mymsg->from->url->host);
+                } else {
+                   char *tmp=NULL;
+                   /* get the Contact Header if present */
+                   osip_message_get_contact(mymsg, 0, &contact);
+                   if (contact) osip_contact_to_str(contact, &tmp);
+                   if (tmp) strncpy(client_id.idstring, tmp, CLIENT_ID_SIZE-1);
+                } /* if from header */
+
+            /* Incoming call (RQ in,  RS out => use the "to" field to identify local client */
+            } else { /*(MSG_IS_REQUEST(mymsg) && direction == DIR_INCOMING) ||
+                       (!MSG_IS_REQUEST(mymsg) && direction == DIR_OUTGOING)) */
+
+                /* I have a full TO SIP URI 'user@host' */
+                if (mymsg->to && mymsg->to->url && 
+                    mymsg->to->url->username && mymsg->to->url->host) {
+                   snprintf(client_id.idstring, CLIENT_ID_SIZE-1, "%s@%s", 
+                            mymsg->to->url->username, mymsg->to->url->host);
+                } else {
+                   char *tmp=NULL;
+                   /* get the Contact Header if present */
+                   osip_message_get_contact(mymsg, 0, &contact);
+                   if (contact) osip_contact_to_str(contact, &tmp);
+                   if (tmp) strncpy(client_id.idstring, tmp, CLIENT_ID_SIZE-1);
+                } /* if to header */
+            }
 
             /* store the IP address of the sender */
             memcpy(&client_id.from_ip, &ticket->from.sin_addr,
                    sizeof(client_id.from_ip));
 
+
             /*
              * is this an RTP stream ? If yes, set 'isrtp=1'
              */
