@@ -46,11 +46,7 @@
    #include "dejitter.h"
 #endif
 
-#if !defined(SOL_IP)
-#define SOL_IP IPPROTO_IP
-#endif
-
-static char const ident[]="$Id: rtpproxy_relay.c,v 1.53 2008/03/22 11:43:36 hb9xar Exp $";
+static char const ident[]="$Id: rtpproxy_relay.c,v 1.57 2009/07/30 17:02:28 hb9xar Exp $";
 
 /* configuration storage */
 extern struct siproxd_config configuration;
@@ -349,7 +345,10 @@ static void *rtpproxy_main(void *arg) {
                                   count, 0, (const struct sockaddr *)&dst_addr,
                                   (socklen_t)sizeof(dst_addr));
                      if (sts == -1) {
-                        if (errno != ECONNREFUSED) {
+                        /* ECONNREFUSED: Got ICMP destination unreachable
+                         * ENOBUFS: Full TX queue, packet dropped (FreeBSD for example)
+                         */
+                        if ((errno != ECONNREFUSED) && (errno != ENOBUFS)){
                            osip_call_id_t callid;
 
                            ERROR("sendto() [%s:%i size=%i] call failed: %s",
@@ -359,7 +358,9 @@ static void *rtpproxy_main(void *arg) {
                            /* if sendto() fails with bad filedescriptor,
                             * this means that the opposite stream has been
                             * canceled or timed out.
-                            * we should then cancel this stream as well.*/
+                            * we should then cancel this stream as well.
+                            * But only this specific media stream and not all
+                            * active media streams in this ongoing call! */
 
                            WARN("stopping opposite stream");
                            callid.number=rtp_proxytable[i].callid_number;
@@ -367,7 +368,8 @@ static void *rtpproxy_main(void *arg) {
                            /* don't lock the mutex, as we own the lock already */
                            sts = rtp_relay_stop_fwd(&callid,
                                                     rtp_proxytable[i].direction,
-                                                    -1, NOLOCK_FDSET);
+                                                    rtp_proxytable[i].media_stream_no,
+                                                    NOLOCK_FDSET);
                            if (sts != STS_SUCCESS) {
                               /* force the streams to timeout on next occasion */
                               rtp_proxytable[i].timestamp=0;
@@ -380,7 +382,10 @@ static void *rtpproxy_main(void *arg) {
                                count, 0, (const struct sockaddr *)&dst_addr,
                                (socklen_t)sizeof(dst_addr));
                   if (sts == -1) {
-                     if (errno != ECONNREFUSED) {
+                     /* ECONNREFUSED: Got ICMP destination unreachable
+                      * ENOBUFS: Full TX queue, packet dropped (FreeBSD for example)
+                      */
+                     if ((errno != ECONNREFUSED) && (errno != ENOBUFS)){
                         osip_call_id_t callid;
 
                         ERROR("sendto() [%s:%i size=%i] call failed: %s",
@@ -398,7 +403,8 @@ static void *rtpproxy_main(void *arg) {
                         /* don't lock the mutex, as we own the lock already */
                         sts = rtp_relay_stop_fwd(&callid,
                                                  rtp_proxytable[i].direction,
-                                                 -1, NOLOCK_FDSET);
+                                                 rtp_proxytable[i].media_stream_no,
+                                                 NOLOCK_FDSET);
                         if (sts != STS_SUCCESS) {
                            /* force the streams to timeout on next occasion */
                            rtp_proxytable[i].timestamp=0;
@@ -408,8 +414,9 @@ static void *rtpproxy_main(void *arg) {
 #endif
                }
             } /* count > 0 */
+
             /* update timestamp of last usage for both (RX and TX) entries.
-             * This allows silence (no data) on one stream without breaking
+             * This allows silence (no data) on one direction without breaking
              * the connection after the RTP timeout */
             rtp_proxytable[i].timestamp=current_tv.tv_sec;
             if (rtp_proxytable[i].opposite_entry > 0) {
@@ -520,7 +527,7 @@ int rtp_relay_start_fwd (osip_call_id_t *callid, client_id_t client_id,
 
    DEBUGC(DBCLASS_RTP,"rtp_relay_start_fwd: starting RTP proxy "
           "stream for: CallID=%s@%s [Client-ID=%s] (%s) #=%i",
-          callid->number, callid->host, client_id.contact,
+          callid->number, callid->host, client_id.idstring,
           ((rtp_direction == DIR_INCOMING) ? "incoming RTP" : "outgoing RTP"),
           media_stream_no);
 
@@ -549,8 +556,7 @@ int rtp_relay_start_fwd (osip_call_id_t *callid, client_id_t client_id,
          (compare_callid(callid, &cid) == STS_SUCCESS) &&
          (rtp_proxytable[i].direction == rtp_direction) &&
          (rtp_proxytable[i].media_stream_no == media_stream_no) &&
-         (compare_client_id(rtp_proxytable[i].client_id, client_id) ==
-            STS_SUCCESS)) {
+         (compare_client_id(rtp_proxytable[i].client_id, client_id) == STS_SUCCESS)) {
          /*
           * The RTP port number reported by the UA MAY change
           * for a given media stream
@@ -775,7 +781,7 @@ int rtp_relay_start_fwd (osip_call_id_t *callid, client_id_t client_id,
           "stream for: CallID=%s@%s [Client-ID=%s] %s #=%i idx=%i",
           rtp_proxytable[freeidx].callid_number,
           rtp_proxytable[freeidx].callid_host,
-          rtp_proxytable[freeidx].client_id.contact,
+          rtp_proxytable[freeidx].client_id.idstring,
           ((rtp_proxytable[freeidx].direction == DIR_INCOMING) ? "incoming RTP" : "outgoing RTP"),
           rtp_proxytable[freeidx].media_stream_no, freeidx);
 
@@ -1026,12 +1032,27 @@ static void match_socket (int rtp_proxytable_idx) {
            (media_stream_no == rtp_proxytable[j].media_stream_no) &&
            (rtp_direction != rtp_proxytable[j].direction) /* channel: &&
            (channel == rtp_proxytable[j].channel)*/ ) {
+         char remip1[16], remip2[16];
+         char lclip1[16], lclip2[16];
+         
+         /* connect the two sockets */
          rtp_proxytable[rtp_proxytable_idx].rtp_tx_sock = rtp_proxytable[j].rtp_rx_sock;
          rtp_proxytable[rtp_proxytable_idx].rtp_con_tx_sock = rtp_proxytable[j].rtp_con_rx_sock;
-         DEBUGC(DBCLASS_RTP, "connected entry %i (fd=%i) <-> entry %i (fd=%i)",
+
+         strcpy(remip1, utils_inet_ntoa(rtp_proxytable[j].remote_ipaddr));
+         strcpy(lclip1, utils_inet_ntoa(rtp_proxytable[j].local_ipaddr));	
+         strcpy(remip2, utils_inet_ntoa(rtp_proxytable[rtp_proxytable_idx].remote_ipaddr));
+         strcpy(lclip2, utils_inet_ntoa(rtp_proxytable[rtp_proxytable_idx].local_ipaddr));
+
+         DEBUGC(DBCLASS_RTP, "connected entry %i (fd=%i, %s:%i->%s:%i) <-> entry %i (fd=%i, %s:%i->%s:%i)",
                              j, rtp_proxytable[j].rtp_rx_sock,
+                             lclip1, rtp_proxytable[j].local_port,
+                             remip1, rtp_proxytable[j].remote_port,
                              rtp_proxytable_idx,
-                             rtp_proxytable[rtp_proxytable_idx].rtp_rx_sock);
+                             rtp_proxytable[rtp_proxytable_idx].rtp_rx_sock,
+                             lclip2, rtp_proxytable[rtp_proxytable_idx].local_port,
+                             remip2, rtp_proxytable[rtp_proxytable_idx].remote_port
+                             );
          break;
       }
    }
