@@ -40,7 +40,7 @@
 #include "plugins.h"
 #include "log.h"
 
-static char const ident[]="$Id: siproxd.c,v 1.78 2008/02/04 20:36:48 hb9xar Exp $";
+static char const ident[]="$Id: siproxd.c,v 1.80 2009/01/07 20:37:11 hb9xar Exp $";
 
 /* configuration storage */
 struct siproxd_config configuration;
@@ -86,6 +86,7 @@ static cfgopts_t main_cfg_opts[] = {
    { "obscure_loops",       TYP_INT4,   &configuration.obscure_loops },
    { "plugindir",           TYP_STRING, &configuration.plugin_dir },
    { "load_plugin",         TYP_STRINGA,&configuration.load_plugin },
+   { "sip_dscp",            TYP_INT4,   &configuration.sip_dscp },
    {0, 0, 0}
 };
 
@@ -454,8 +455,8 @@ int main (int argc, char *argv[])
          osip_message_get_max_forwards(ticket.sipmsg, 0, &max_forwards);
          if (max_forwards && max_forwards->hvalue) {
             forwards_count = atoi(max_forwards->hvalue);
-            if ((forwards_count<=0)||
-                (forwards_count>=LONG_MAX)) forwards_count=DEFAULT_MAXFWD;
+            if ((forwards_count<0)||
+                (forwards_count>255)) forwards_count=DEFAULT_MAXFWD;
          }
 
          DEBUGC(DBCLASS_PROXY,"checking Max-Forwards (=%i)",forwards_count);
