@@ -46,7 +46,7 @@
 #include "siproxd.h"
 #include "log.h"
 
-static char const ident[]="$Id: utils.c,v 1.53 2008/01/19 16:07:14 hb9xar Exp $";
+static char const ident[]="$Id: utils.c,v 1.55 2009/07/30 17:02:28 hb9xar Exp $";
 
 /* configuration storage */
 extern struct siproxd_config configuration;
@@ -307,7 +307,7 @@ void secure_enviroment (void) {
          sts = chroot(configuration.chrootjail);
 	 if (sts != 0) DEBUGC(DBCLASS_CONFIG,"chroot(%s) failed: %s",
 	                      configuration.chrootjail, strerror(errno));
-         chdir("/");
+         sts=chdir("/");
       }
 
       /*
@@ -607,18 +607,18 @@ int createpidfile(char *pidfilename) {
 int  compare_client_id(client_id_t cid1, client_id_t cid2) {
 
    /* Prio 1: Contact - if present in both structures */
-   if ((cid1.contact[0] != '\0') && (cid2.contact[0] != '\0')) {
-      if (strncmp(cid1.contact, cid2.contact, CLIENT_ID_SIZE) == 0) {
+   if ((cid1.idstring[0] != '\0') && (cid2.idstring[0] != '\0')) {
+      if (strncmp(cid1.idstring, cid2.idstring, CLIENT_ID_SIZE) == 0) {
          DEBUGC(DBCLASS_BABBLE, "compare_client_id: contact match [%s]",
-                cid1.contact);
+                cid1.idstring);
          return STS_SUCCESS;
       }
       DEBUGC(DBCLASS_BABBLE, "compare_client_id: contact NO match [%s<->%s]",
-             cid1.contact, cid2.contact);
+             cid1.idstring, cid2.idstring);
       return STS_FAILURE;
    }
 
-   /* Prio 2: IP (always present) */
+   /* Prio 2: IP (always present) - fallback, if no ID string present. */
    if (memcmp(&cid1.from_ip, &cid2.from_ip, sizeof(struct in_addr)) == 0) {
       DEBUGC(DBCLASS_BABBLE, "compare_client_id: IP match [%s]",
              utils_inet_ntoa(cid1.from_ip));
